'From Squeak3.7beta of ''1 April 2004'' [latest update: #5905] on 19 May 2004 at 10:46:44 pm'!
"Change Set:		SyntaxFixes
Date:			19 May 2004
Author:			Anthony Hannan

Fixes about 10 methods in 3.7 that have extra periods where they don't belong, either after a method header, comment, or other period. Also fixes one method that a space between negation sign and number. These syntax fixes were need for the new closure compiler to parse them correctly."!


!Bag methodsFor: 'comparing' stamp: 'ajh 5/19/2004 22:36'!
= aBag
	"Two bags are equal if
	 (a) they are the same 'kind' of thing.
	 (b) they have the same size.
	 (c) each element occurs the same number of times in both of them"

	(aBag isKindOf: Bag) ifFalse: [^false].
	self size = aBag size ifFalse: [^false].
	contents associationsDo: [:assoc|
		(aBag occurrencesOf: assoc key) = assoc value
			ifFalse: [^false]].
	^true

! !


!Celeste class methodsFor: 'class initialization' stamp: 'ajh 5/19/2004 22:37'!
addPreferenceForCelesteDespam
	Preferences preferenceAt: #celesteDespam ifAbsent: [
		Preferences addPreference: #celesteDespam categories: #('general') default: false balloonHelp: 'enable de-spamming option in Celeste'.
	].! !


!Date methodsFor: 'deprecated' stamp: 'ajh 5/19/2004 22:33'!
daylightSavingsInEffect
	"Return true if DST is observed at or after 2am on this day"

	self deprecated: 'Deprecated'.

	self dayMonthYearDo: 
		[ :day :month :year |
		(month < 4 or: [month > 10]) ifTrue: [^ false].  "False November through March"
		(month > 4 and: [month < 10]) ifTrue: [^ true].  "True May through September"
		month = 4
		ifTrue:	["It's April -- true on first Sunday or later"
				day >= 7 ifTrue: [^ true].  "Must be after"
				^ day > (self weekdayIndex \\ 7)]
		ifFalse: ["It's October -- false on last Sunday or later"
				day <= 24 ifTrue: [^ true].  "Must be before"
				^ day <= (24 + (self weekdayIndex \\ 7))]]! !


!Dictionary methodsFor: 'comparing' stamp: 'ajh 5/19/2004 22:36'!
= aDictionary
	"Two dictionaries are equal if
	 (a) they are the same 'kind' of thing.
	 (b) they have the same set of keys.
	 (c) for each (common) key, they have the same value"

	(aDictionary isKindOf: Dictionary) ifFalse: [^false].
	self size = aDictionary size ifFalse: [^false].
	self associationsDo: [:assoc|
		(aDictionary at: assoc key ifAbsent: [^false]) = assoc value
			ifFalse: [^false]].
	^true

! !


!IRBuilderMock methodsFor: 'instructions' stamp: 'ajh 5/19/2004 22:41'!
setField: instVarIndex
	self addInstruction: #setField:.! !


!InternalThreadNavigationMorph methodsFor: 'initialization' stamp: 'ajh 5/19/2004 22:39'!
addButtons

	| marginPt i sz data images pageNumber f m b1 b2 dot arrowWidth arrowCenter vertices arrowHeight nameMorph sizeRatio controlsColor |

	sizeRatio _ self sizeRatio.
	controlsColor _ Color orange lighter.

	self changeNoLayout.
	self hResizing: #rigid.
	self vResizing: #rigid.
	marginPt _ (4 @ 4 * sizeRatio) rounded.
	i _ self currentIndex.
	sz _ self myThumbnailSize.
	arrowWidth _ (14 * sizeRatio) rounded.
	arrowHeight _ (14 * sizeRatio) rounded.
	data _ {
		{i - 1. 'Previous:'. #previousPage. #leftCenter. arrowWidth. 'Prev'}.
		{i + 1. 'Next:'. #nextPage. #rightCenter. arrowWidth negated. 'Next'}
	}.
	images _ data collect: [ :tuple |
		pageNumber _ tuple first.
		(pageNumber between: 1 and: listOfPages size) ifTrue: [
			f _ self 
				makeThumbnailForPageNumber: pageNumber 
				scaledToSize: sz 
				default: tuple sixth.
			f _ f deepCopy.		"we're going to mess it up"
			arrowCenter _ f boundingBox perform: tuple fourth.
			vertices _ {
				arrowCenter + (tuple fifth @ arrowHeight negated).
				arrowCenter + (tuple fifth @ arrowHeight).
				arrowCenter.
			}.
			f getCanvas
				drawPolygon: vertices 
				color: controlsColor
				borderWidth: 0 
				borderColor: Color transparent.
			m _ ImageMorph new image: f.
			m setBalloonText: tuple second translated,' ',(listOfPages at: pageNumber) first.
			m addMouseUpActionWith: (
				MessageSend receiver: self selector: tuple third
			).
		] ifFalse: [
			f _ (Form extent: sz depth: 16) fillColor: Color lightGray.
			m _ ImageMorph new image: f.
		].
		m
	].
	b1 _ images first.
	b2 _ images second.
	dot _ EllipseMorph new extent: (18@18 * sizeRatio) rounded; color: controlsColor; borderWidth: 0.

	self addMorph: (b1 position: self position + marginPt).
	self addMorph: (b2 position: b1 topRight + (marginPt x @ 0)).

	self extent: (b1 bottomRight max: b2 bottomRight) - self position + marginPt.
	self addMorph: dot.
	dot align: dot center with: b1 bounds rightCenter + ((marginPt x @ 0) // 2).
	dot setBalloonText: threadName,'
more commands'.
	dot on: #mouseDown send: #moreCommands to: self.
	self fullBounds.
	self addMorph: (nameMorph _ SquishedNameMorph new).
	nameMorph
		target: self getSelector: #threadName setSelector: nil;
		color: Color transparent;
		width: self width;
		height: (15 * sizeRatio) rounded;
		align: nameMorph bottomLeft with: self bottomLeft.

! !


!PluggableMessageCategoryListMorph methodsFor: 'as yet unclassified' stamp: 'ajh 5/19/2004 22:38'!
on: anObject list: getListSel selected: getSelectionSel changeSelected: setSelectionSel menu: getMenuSel keystroke: keyActionSel getRawListSelector: getRawSel
	self model: anObject.
	getListSelector _ getListSel.
	getIndexSelector _ getSelectionSel.
	setIndexSelector _ setSelectionSel.
	getMenuSelector _ getMenuSel.
	keystrokeActionSelector _ keyActionSel.
	autoDeselect _ true.
	self borderWidth: 1.
	getRawListSelector _ getRawSel.
	self updateList.
	self selectionIndex: self getCurrentSelectionIndex.
	self initForKeystrokes! !


!PluggableMultiColumnListMorph methodsFor: 'initialization' stamp: 'ajh 5/19/2004 22:39'!
list: arrayOfLists 
	| listOfStrings |
	lists _ arrayOfLists.
	scroller removeAllMorphs.
	listOfStrings _ arrayOfLists == nil
				ifTrue: [Array new]
				ifFalse: [
					arrayOfLists isEmpty ifFalse: [
					arrayOfLists at: 1]].
	list _ listOfStrings
				ifNil: [Array new].
	self listMorph listChanged.

	self setScrollDeltas.
	scrollBar setValue: 0.0! !


!SocketStreamTest methodsFor: 'running' stamp: 'ajh 5/19/2004 22:40'!
testNextColonBug
	stream2 timeout: 1.
	stream1 nextPutAll: '12345678'; flush.
	stream2 next: 4.
	"self should: [stream2 next: 8] raise: ConnectionTimedOut"
	self assert: false.
	"md: doesn't timeOut for me... just hangs"! !

!SocketStreamTest methodsFor: 'running' stamp: 'ajh 5/19/2004 22:40'!
testNextColonConnectionTimeout
	"
	stream1 nextPutAll: '12345'; flush.
	stream2 timeout: 1.
	self should: [stream2 next: 10] raise: ConnectionTimedOut.
	stream1 nextPutAll: '67890'; flush.
	self assert: (stream2 next: 10) size = 10
	"
	self assert: false.
	"md: doesn't timeOut for me... just hangs"! !


!TestRunner methodsFor: 'interface opening' stamp: 'ajh 5/19/2004 22:34'!
buildLowerPanes
	| failuresList errorsList row tHeight divider |
	row _ AlignmentMorph newColumn hResizing: #spaceFill;
				 vResizing: #spaceFill;
				 layoutInset: 0;
				 borderWidth: 1;
				 borderColor: Color black;
				 layoutPolicy: ProportionalLayout new.
	self buildPassFailText.
	self buildDetailsText.
	self buildTestsList.
	failuresList _ self buildFailuresList.
	errorsList _ self buildErrorsList.
	tHeight _ 26.
	divider _ Array new: 3.
	1
		to: divider size
		do: [:index | 
			divider at: index put: BorderedSubpaneDividerMorph forBottomEdge.
			Preferences alternativeWindowLook
				ifTrue: [(divider at: index) extent: 4 @ 4;
						 color: Color transparent;
						 borderColor: #raised;
						 borderWidth: 2]].
	row
		addMorph: (passFailText borderWidth: 0)
		fullFrame: (LayoutFrame
				fractions: (0 @ 0 corner: 1 @ 0)
				offsets: (0 @ 0 corner: 0 @ tHeight - 1)).
	row
		addMorph: (divider at: 1)
		fullFrame: (LayoutFrame
				fractions: (0 @ 0 corner: 1 @ 0)
				offsets: (0 @ (tHeight - 1) corner: 0 @ tHeight)).
	row
		addMorph: (detailsText borderWidth: 0)
		fullFrame: (LayoutFrame
				fractions: (0 @ 0 corner: 1 @ 0)
				offsets: (0 @ tHeight corner: 0 @ (2 * tHeight - 1))).
	row
		addMorph: (divider at: 2)
		fullFrame: (LayoutFrame
				fractions: (0 @ 0 corner: 1 @ 0)
				offsets: (0 @ (2 * tHeight - 1) corner: 0 @ (2 * tHeight))).
	row
		addMorph: (failuresList borderWidth: 0)
		fullFrame: (LayoutFrame
				fractions: (0 @ 0 corner: 1 @ 0.6)
				offsets: (0 @ (2 * tHeight) corner: 0 @ -1)).
	row
		addMorph: (divider at: 3)
		fullFrame: (LayoutFrame
				fractions: (0 @ 0.6 corner: 1 @ 0.6)
				offsets: (0 @ -1 corner: 0 @ 0)).
	row
		addMorph: (errorsList borderWidth: 0)
		fullFrame: (LayoutFrame
				fractions: (0 @ 0.6 corner: 1 @ 1)
				offsets: (0 @ 0 corner: 0 @ 0)).
	^ row! !

